-- File: archive\db\sql\save\twh_getrenamedlob.sql
-- SID: 1.3
-- Date Modified: 02/01/30 15:14:23
--
-- Module Description
--   Defines the twh_getrenamedlob stored procedure

USE Object
GO

---------------------------------------------------------------------------------------------------
-- twh_getrenamedlob
PRINT 'Creating procedure twh_getrenamedlob'
GO

IF EXISTS (SELECT * FROM sysobjects WHERE name = 'twh_getrenamedlob' AND type = 'P')
  DROP PROCEDURE twh_getrenamedlob
GO

-- File: archive\db\sql\save\twh_getrenamedlob.sql
-- SID: 1.3
-- Date Modified: 02/01/30 15:14:23
/*
Gets LOBs that have been renamed since the last load to the warehouse
Returns the following:
  id:   The LOB that was renamed.  LOBs that are pointers to other LOBs are not processed
    by this, as the warehouse does not store them with their named, but rather
    represents them as the linked LOB with multiple parents.
  newname: The new name of the LOB
  changedate: The mod time of the LOB
*/
CREATE PROCEDURE twh_getrenamedlob
AS
  SET NOCOUNT ON
  --Get GM time offset
  DECLARE @gmoffsetmin INT

  EXEC master..xp_regread 
    'HKEY_LOCAL_MACHINE',
    'SYSTEM\CurrentControlSet\Control\TimeZoneInformation',
    'ActiveTimeBias', 
     @gmoffsetmin OUTPUT

  --First reset any rename records that did not make it to the warehouse
  UPDATE twh_lob SET name=oldname, oldname=NULL, status=status-2 WHERE status&2=2

  CREATE TABLE #renamedlob
  (
    id ObjID,
    newname ObjName,
    changedate DATETIME
  )
  INSERT INTO #renamedlob
    SELECT o.id, o.name, o.mtime
    FROM LineOfBusiness_V o, twh_lob t, link l
      WHERE o.id=t.id AND l.link_type='LOBC' AND l.dst_cid='LOB' AND l.dst_id=o.id AND l.deleted=0
      AND t.linkedid IS NULL AND t.name<>o.name
  --Update the lob_twh table setting name, oldname, and the status bit for pending rename.
  UPDATE t SET oldname=t.name, name=r.newname, status=status+2
    FROM twh_lob t, #renamedlob r
    WHERE t.id=r.id
  --Return records to the warehouse
  SELECT id, NULL AS comp_id, newname, DATEADD(mi, @gmoffsetmin, changedate) AS changedate FROM #renamedlob
GO
